<?php
/*
Part of the Ad Injection plugin for WordPress
http://www.reviewmylife.co.uk/
*/

/*  Copyright 2010 reviewmylife (contact : http://www.reviewmylife.co.uk/)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 2, as 
	published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if (!is_admin()) return;

$adinj_warning_msg_chmod = "";
$adinj_warning_msg_filewrite = "";

function adinj_checkNonce(){
	if (empty($_POST) || !check_admin_referer('_adinj_form', '_adinj_nonce')){
		echo 'form error';
		exit();
	}
}

function adinj_update_options($ops){
	update_option('adinj_options', $ops);
	// Refresh options from database as cached values are now invalidated
	global $adinj_data;
	$adinj_data = get_option('adinj_options');
}

function adinj_save_options(){
	// TODO investigate register_settings for a future release
	if (isset($_POST['adinj_action'])){
	switch($_POST['adinj_action']){
	case 'Save all settings':
		adinj_checkNonce();
		
		// Extract all know options
		$default_options = adinj_default_options();
		foreach ($default_options as $key => $value){
			if (isset($_POST[$key])){
				$ops[$key] = $_POST[$key];
			} else {
				$ops[$key] = "";
			}
		}
		
		$raw_ad_code_random = stripslashes($_POST['ad_code_random_1']);
		$ops['ad_code_random_1'] = $raw_ad_code_random;
		
		$raw_ad_code_top = stripslashes($_POST['ad_code_top_1']);
		$ops['ad_code_top_1'] = $raw_ad_code_top;
		
		$raw_ad_code_bottom = stripslashes($_POST['ad_code_bottom_1']);
		$ops['ad_code_bottom_1'] = $raw_ad_code_bottom;
		
		$ad_referrers = stripslashes($_POST['ad_referrers']); // TODO do i need strip slashes?
		$ops['ad_referrers'] = $ad_referrers;
		
		$blocked_ips = stripslashes($_POST['blocked_ips']);
		$ops['blocked_ips'] = $blocked_ips;
		
		adinj_update_options($ops);
		
		if ($ops['ad_insertion_mode'] == 'mfunc') {
			write_ad_to_file($raw_ad_code_random, ADINJ_AD_PATH.'/'.ADINJ_AD_RANDOM_FILE);
			write_ad_to_file($raw_ad_code_top, ADINJ_AD_PATH.'/'.ADINJ_AD_TOP_FILE);
			write_ad_to_file($raw_ad_code_bottom, ADINJ_AD_PATH.'/'.ADINJ_AD_BOTTOM_FILE);
			adinj_write_config_file();
		}

		break;

		case 'Reset to Default':
		adinj_checkNonce();
		adinj_update_options(adinj_default_options());
		break;
		
		case 'Delete settings from DB':
		adinj_checkNonce();
		delete_option('adinj_options');
		
		case 'Delete widget settings from DB':
		adinj_checkNonce();
		delete_option('widget_adinj');
		// TODO add option to delete ads files as well
		break;
	}
	}
}

// Test reminder: These generated functions won't exist until the first save
// so be careful if adding any new ones - they might not exist yet, but could
// still be referenced by adshow.
function adinj_write_config_file(){
	$ops = adinj_options();
	if ($ops['ad_insertion_mode'] != 'mfunc') return;
	$referrer_list = adinj_quote_list('ad_referrers');
	$ip_list = adinj_quote_list('blocked_ips');
	$sevisitors_only = adinj_ticked('sevisitors_only')?'true':'false';
	$debug_mode = adinj_ticked('debug_mode')?'true':'false';
	
	$rnd_func = adinj_add_tags(NULL, 'rnd_', 'adinj_config_add_tags_rnd');
	$top_func = adinj_add_tags(NULL, 'top_', 'adinj_config_add_tags_top');
	$bottom_func = adinj_add_tags(NULL, 'bottom_', 'adinj_config_add_tags_bottom');
	
	$config = <<<CONFIG
<?php
/*
Ad Injection config file
DO NOT EDIT MANUALLY
This file is generated by Ad Injection
*/

function adinj_config_sevisitors_only() { return $sevisitors_only; }
function adinj_config_search_engine_referrers() { return array($referrer_list); }
function adinj_config_blocked_ips() { return array($ip_list); }
function adinj_config_debug_mode() { return $debug_mode; }
$rnd_func
$top_func
$bottom_func

?>
CONFIG;

	adinj_write_file(ADINJ_CONFIG_FILE, $config, 0640);

}

function adinj_write_file($path, $content, $permission){
	$ops = adinj_options();
	global $adinj_warning_msg_filewrite;
	
	$dir = dirname($path);
	if (!@file_exists($dir)){
		if (!@mkdir($dir, 0750)){
			@mkdir($dir, 0755) or $adinj_warning_msg_filewrite .= "<br />Warning: could not create dir: ".$dir.". Please create it manually and try again.";
		}		
	}
	
	$handle = @fopen($path, "w");
	if (strlen($content) > 0){
		@fwrite($handle, $content) or $adinj_warning_msg_filewrite .= "<br />Warning: could not write to file: $path";
	}
	@fclose($handle);
	if (@file_exists($path)){
		adinj_chmod($path, $permission);
	}
}

function adinj_chmod($path, $permission){
	global $adinj_warning_msg_chmod;
	$oldperm = substr(decoct(@fileperms($path)), -3);
	$newperm = decoct($permission);
	if ($newperm == $oldperm) return;
	@chmod($path, $permission) or $adinj_warning_msg_chmod .=  "<br />Warning: chmod $permission " .
		"on $path failed. Current permissions: $oldperm<br />	Try manually updating the permission if problems occur.";
}

function adinj_get_logo(){
	return '<a href="http://www.reviewmylife.co.uk/" target="_new"><img src="'. WP_PLUGIN_URL . '/ad-injection/rml-micro-logo.png" width="16" height="16" border="0" alt="reviewmylife" /></a>';
}
	
function adinj_options_page(){
	adinj_save_options();
	
	$ops = adinj_options();
	if ($ops === false || adinj_options_need_upgrading($ops)){
		// Upgraded via FTP without being deactivated/reactivated
		adinj_activate_hook();
	}
	$ops = adinj_options(1);
	if ($ops['ad_insertion_mode'] == 'mfunc') {
		if (!@file_exists(ADINJ_CONFIG_FILE)){
			adinj_write_config_file();
		}
	}
	
	echo '<div class="wrap">';

	if (adinj_problem_with_wpminify_check()){
		echo '<div id="ad-injection-warning" class="error"><p><strong>';
		echo adinj_get_problem_with_wpminify_message();
		echo '</strong></p></div>';
	}
	
	echo '<div id="icon-options-general" class="icon32"></div><h2>Ad Injection ' . adinj_get_version() . adinj_get_logo() . '</h2>';
	
	if (isset($_POST['adinj_action'])) {
        echo '<div id="message" class="updated below-h2"><p><strong>';
        echo 'All settings saved: ';
		if (is_plugin_active('wp-super-cache/wp-cache.php')) {
			echo "You might need to <a href='options-general.php?page=wpsupercache&amp;tab=tester'>clear your WP Super Cache cache</a> for the settings to take effect.";
		} else {
			echo "If you are using a caching plugin you might need to delete its cache for any changes to take effect.";
        }
		echo '</strong>';
		if ($ops['ad_insertion_mode']=='mfunc'){
			global $adinj_warning_msg_filewrite;
			if (!empty($adinj_warning_msg_filewrite)){
				echo $adinj_warning_msg_filewrite;
				echo "<br />Workaround: If you are unable to fix these errors you will have to switch to a <a href='#restrictions'>direct insertion mode</a> (however dynamic features won't work if you are using a caching plugin).";
			}
		}
		global $adinj_warning_msg_chmod;
		if (!empty($adinj_warning_msg_chmod)){
			echo '<br />Info: Some warnings were generated by chmod. See the <a href="#debugging">debugging</a> section for more info.';
		}
		if ($ops['ads_enabled'] != 'on'){
			echo '<br /><font color="red">Warning: Ads are not enabled. You need to turn the ads on for everyone to see them.</font>';
		}
		echo '</p></div>';
		
    } else {
		echo '<div id="message" class="updated below-h2"><p style="line-height:140%"><strong>';
		echo "24th December 2010: I'll be taking a break from updating Ad Injection over Christmas and the New Year. The next release will probably be on the 5th January. But please keep sending me any <a href='https://spreadsheets.google.com/viewform?formkey=dFUwZzBYcG1HNzNKMmJZdWFDdFhkY0E6MQ' target='_new'>feedback or bug reports</a>. I read and act on all feedback! Merry Christmas :)";
		echo '</strong></p></div>';
	}
	?>
	
	
	
	<div style="width:258px; float:right;">
	<div class="postbox-container" style="width:258px;">
		<div class="metabox-holder">	
		<div class="meta-box-sortables" style="min-height:50px;">
		<div id="toc" class="postbox">
		<h3 class="hndle"><span><?php echo adinj_get_logo(); ?> Status</span></h3>
		<div class="inside" style="margin:5px;">
			<table border="0" cellpadding="2">
			<tr><td style="text-align:right; vertical-align:top">
			<b><a href="#global">Ads enabled</a></b>
			</td><td>
			<?php 
			$info = adinj_get_status('global'); echo adinj_dot($info[0]).' '.$info[1];
			if ($info[0] != 'red') {	?>
			<br />&nbsp;&nbsp;<?php echo adinj_green_or_red_dot('exclude_home'); ?> home
			<br />&nbsp;&nbsp;<?php echo adinj_green_or_red_dot('exclude_page'); ?> page
			<br />&nbsp;&nbsp;<?php echo adinj_green_or_red_dot('exclude_single'); ?> single
			<br />&nbsp;&nbsp;<?php echo adinj_green_or_red_dot('exclude_archive'); ?> archive
			</td></tr>
			<tr><td style="text-align:right; vertical-align:top">
			<b><a href="#random">Random ads</a></b>
			</td><td>
			<?php 
			$info = adinj_get_status('random'); echo adinj_dot($info[0]).' '.$info[1].'<br />'; 
			$info = adinj_get_status('random_home'); echo adinj_dot($info[0]).' '.$info[1];
			?>
			</td></tr>
			<tr><td style="text-align:right">
			<b><a href="#topad">Top ad</a></b>
			</td><td>
			<?php $info = adinj_get_status('topad'); echo adinj_dot($info[0]).' '.$info[1]; ?>
			</td></tr>
			<tr><td style="text-align:right">
			<b><a href="#bottomad">Bottom ad</a></b>
			</td><td>
			<?php $info = adinj_get_status('bottomad'); echo adinj_dot($info[0]).' '.$info[1]; ?>
			</td></tr>
			<tr><td style="text-align:right; vertical-align:top">
			<b><a href="#widgets">Widgets</a></b>
			</td><td>
			<?php $info = adinj_get_status('widgets'); echo adinj_dot($info[0]).' '.$info[1]; 
			if ($info[0] != 'red') {	?>
			<br />&nbsp;&nbsp;<?php echo adinj_green_or_red_dot('widget_exclude_home'); ?> home
			<br />&nbsp;&nbsp;<?php echo adinj_green_or_red_dot('widget_exclude_page'); ?> page
			<br />&nbsp;&nbsp;<?php echo adinj_green_or_red_dot('widget_exclude_single'); ?> single
			<br />&nbsp;&nbsp;<?php echo adinj_green_or_red_dot('widget_exclude_archive'); ?> archive
			<?php } ?>
			</td></tr>
			<tr><td style="text-align:right">
			<b><a href="#restrictions">Mode</a></b>
			</td><td>
			<?php $info = adinj_get_status('mode'); echo adinj_dot($info[0]).' '.$info[1]; ?>
			</td></tr>
			<tr><td style="text-align:right">
			<b><a href="#dynamic">Restrictions</a></b>
			</td><td>
			<?php $info = adinj_get_status('restrictions'); echo adinj_dot($info[0]).' '.$info[1]; ?>
			</td></tr>
			<tr><td style="text-align:right">
			<b><a href="#debugging">Debug mode</a></b>
			</td><td>
			<?php $info = adinj_get_status('debugging'); echo adinj_dot($info[0]).' '.$info[1]; ?>
			</td></tr>
			<tr><td>
			</td><td>
			</td></tr>
			<tr><td>
			</td><td>
			<?php } ?>
			</td></tr>
			</table>
		</div>
		</div>	
		</div>
		</div>
	</div> 	
	
	<br />
	
	<div class="postbox-container" style="width:258px;">
		<div class="metabox-holder">	
		<div class="meta-box-sortables">
		<div id="toc" class="postbox">
		<h3 class="hndle"><span><?php echo adinj_get_logo(); ?> More info...</span></h3>
		<div class="inside" style="margin:5px;">
			<h4>More Ad Injection information</h4>
			<ul>
			<li><a href="http://www.reviewmylife.co.uk/blog/2010/12/06/ad-injection-plugin-wordpress/" target="_new">Ad Injection at reviewmylife</a></li>
			<li><a href="http://wordpress.org/extend/plugins/ad-injection/" target="_new">Ad Injection at WordPress</a></li>
			<li><b><a href="https://spreadsheets.google.com/viewform?formkey=dFUwZzBYcG1HNzNKMmJZdWFDdFhkY0E6MQ" target="_new">Report a bug / give feedback</a></b></li>
			</ul>
			<h4>Coming in 2011</h4>
			<ul>
			<li>More precise control over which categories and tags the ads are shown in.</li>
			<li>Extra places where adverts can be inserted.</li>
			</ul>
			
			<h4><font color="red">Important!</font></h4>
			<p>You are responsible for making sure the ad settings and positioning you define are in compliance with your ad provider's terms of service! Failure to do so could get you banned by them!</p>
		
			<h4><font color="red">Beta version</font></h4>
			<p>This plugin has only only recently been released. I'm actively listening to your feedback and fixing any problems, and adding new features that you request. Please let me know if you like the plugin too!</p>
			
			<h4>More by this author</h4>
			<ul>
			<li><a href="http://www.reviewmylife.co.uk/" target="_new">www.reviewmylife.co.uk</a></li>
			<li><a href="http://www.advancedhtml.co.uk/" target="_new">www.advancedhtml.co.uk</a></li>
			</ul>
		</div>
		</div>	
		</div>
		</div>
	</div> 
	</div>
		
	<script type="text/javascript">
	function adinj_addtext(element, value) {
		if (value.length == 0) return;
		separator = ', ';
		if (element.value.length == 0){
			separator = '';
		}
		element.value += (separator + value);
	}
	</script>
	
	<p><a href="#random">Random ads</a> | <a href="#topad">Top</a> | <a href="#bottomad">Bottom</a> | <a href="#widgets">Widgets</a> | <a href="#restrictions">Ad insert mode/dynamic restrictions</a> | <a href="#debugging">Debug</a> | <a href="#docs">Quick Start</a> | <a href="#testads">Test ads</a></p>
	
	<form name="adinjform" method="post" action="">
	<?php wp_nonce_field('_adinj_form', '_adinj_nonce'); ?>
	
	
	<?php adinj_postbox_start(__("Global settings", 'adinj'), 'global'); ?>
	
	<p>These settings apply to all ads (random, top, bottom, and widget). They will override all other settings.</p>
	
	<input type="radio" name="ads_enabled" value="on" <?php if ($ops['ads_enabled']=='on') echo 'checked="checked"'; ?> /> <b>On: <?php _e('Ads enabled', 'adinj') ?></b><br />
	<input type="radio" name="ads_enabled" value="off" <?php if ($ops['ads_enabled']=='off' || $ops['ads_enabled']=='') echo 'checked="checked"'; ?> /> <b>Off</b><br />
	<input type="radio" name="ads_enabled" value="test" <?php if ($ops['ads_enabled']=='test') echo 'checked="checked"'; ?> /> <b>Test mode</b> - Only show ads to admin.<br />
	<span style="font-size:10px;color:red;">Warning: Turn any caching plugin *off* before using test mode. If you leave them on the test adverts will be cached and shown to your real visitors.</span><br />

	<table border="0">
	<tr><td>
	<p><?php _e("Only show ads on pages older than ", 'adinj') ?></p>
	</td><td>
	<p>
	<select name='ads_on_page_older_than'>
	<?php
	$older_than_days = array(0, 1, 2, 3, 5, 7, 10, 14, 21, 28, 40, 50);
	for ($value=0; $value<sizeof($older_than_days); ++$value){
		echo "<option value=\"$older_than_days[$value]\" ";
		if($ops['ads_on_page_older_than'] == $older_than_days[$value]) echo 'selected="selected"';
		echo ">$older_than_days[$value]</option>";
	}
	?>
	</select><?php _e(" (days)", 'adinj') ?> - only for single posts and pages</p>
	</td></tr>
	<tr><td style="vertical-align:top">
	Don't show ads on these page types:
	</td><td>
	<input type="checkbox" name="exclude_home" <?php echo adinj_ticked('exclude_home'); ?> />home - <?php echo get_bloginfo('url'); ?><br />
	<?php
	$count_pages = wp_count_posts('page', 'readable'); 
	$count_posts = wp_count_posts('post', 'readable'); 
	?>
	<input type="checkbox" name="exclude_page" <?php echo adinj_ticked('exclude_page'); ?> />page - <?php echo $count_pages->publish; ?> page(s)<br />
	<input type="checkbox" name="exclude_single" <?php echo adinj_ticked('exclude_single'); ?> />single -<?php echo $count_posts->publish; ?> individual blog post(s)<br />
	<input type="checkbox" name="exclude_archive" <?php echo adinj_ticked('exclude_archive'); ?> />archive - only <a href="#widgets">widgets</a> currently appear on archives<br />
	</td></tr>
	</table>
	
	<b>Category and tag conditions</b>
	
	<?php adinj_condition_table('global_category', 'category slugs. e.g: cat1, cat2, cat3', 'category'); ?>
	
	<?php adinj_condition_table('global_tag', 'tag slugs. e.g: tag1, tag2, tag3', 'tag'); ?>
	
	<?php adinj_postbox_end(); ?>
	
	
	
	
	<?php adinj_postbox_start(__("Randomly Injected ad code", 'adinj'), 'random'); ?>
	
	<table border="0" cellspacing="5">
	<tr><td style="vertical-align: top">
	<textarea name="ad_code_random_1" rows="10" cols="60"><?php echo $ops['ad_code_random_1']; ?></textarea>
	</td><td style="vertical-align: top">
	<?php adinj_add_alignment_options('rnd_'); ?>
	</td></tr>
	<tr><td>
	<?php _e("Always put the first ad after the first paragraph.", 'adinj') ?> <input type="checkbox" name="first_paragraph_ad" <?php echo adinj_ticked('first_paragraph_ad'); ?> />
	</td><td>
	</td></tr>
	</table>

	
	<p><span style="font-size:10px;"><b>Docs:</b> On individual posts or pages this advert is inserted between randomly selected paragraphs. On a multi-post page (e.g. home page), one ad is inserted into each post. Try a <a href="#468x60">468x60</a> or <a href="#728x90">728x90</a> banner.</span></p>
	<p><span style="font-size:10px;">Be especially careful if you decide to use the 'float' layout options. Make sure that you don't have adverts floated over the top of other page elements, or vice-versa.</span></p>
	</div>
	
	<input type="submit" style="float:right" name="adinj_action" value="<?php _e('Save all settings', 'adinj') ?>" />
	<h3><?php _e("Single posts and pages: Randomly Injected ad settings", 'adinj') ?></h3>
	<div class="inside" style="margin:10px">
	<p>These random ad injection settings are specific to individual posts and pages.</p>
	
	<table border="0">
	
	<tr><td>
	<?php _e("Allow multiple ads to be injected at the same positions.", 'adinj') ?>
	</td><td>
	<input type="checkbox" name="multiple_ads_at_same_position" <?php echo adinj_ticked('multiple_ads_at_same_position'); ?> /> (default is to inject ads at unique positions)
	</td></tr>

	
	<tr><td>
	<?php _e("Maximum number of randomly injected ads: ", 'adinj') ?></td><td>
	<select name='max_num_of_ads'>
	<?php
	for ($value=0; $value<=10; ++$value){
		echo "<option value=\"$value\" ";
		if($ops['max_num_of_ads'] == $value) echo 'selected="selected"';
		echo ">$value</option>";
	}
	?>
	</select> <?php echo adinj_getdefault('max_num_of_ads'); ?><br />
	</td></tr>
	
	<tr><td>
	<?php
		_e("No random ads if page shorter than: ", 'adinj');
		echo '</td><td>';
		adinj_selection_box("no_random_ads_if_shorter_than",
			array(ADINJ_RULE_DISABLED, 100, 200, 300, 500, 1000, 1500, 2000, 2500, 3000));
			echo adinj_getdefault('no_random_ads_if_shorter_than');
	?>
	</td></tr>
	
	<tr><td>
	<?php
		_e("Limit of 1 ad if page shorter than: ", 'adinj');
		echo '</td><td>';
		adinj_selection_box("one_ad_if_shorter_than",
			array(ADINJ_RULE_DISABLED, 100, 200, 300, 500, 1000, 1500, 2000, 2500, 3000));
			echo adinj_getdefault('one_ad_if_shorter_than');
	?>
	</td></tr>
	
	<tr><td>
	<?php
		_e("Limit of 2 ads if page shorter than: ", 'adinj');
		echo '</td><td>';
		adinj_selection_box("two_ads_if_shorter_than",
			array(ADINJ_RULE_DISABLED, 100, 200, 300, 500, 1000, 1500, 2000, 2500, 3000, 5000, 10000));
			echo adinj_getdefault('two_ads_if_shorter_than');
	?>
	</td></tr>

	<tr><td>
	<?php
		_e("Limit of 3 ads if page shorter than: ", 'adinj');
		echo '</td><td>';
		adinj_selection_box("three_ads_if_shorter_than",
			array(ADINJ_RULE_DISABLED, 100, 200, 300, 500, 1000, 1500, 2000, 2500, 3000, 5000, 10000, 20000));
			echo adinj_getdefault('three_ads_if_shorter_than');
	?>
	</td></tr>
	</table>
	
	<br clear="all" />
	<p><span style="font-size:10px;"><b>Docs:</b> The above directives are processed in order from top to bottom.</span></p>
	

	<p></p>
	
	</div>
	
	<input type="submit" style="float:right" name="adinj_action" value="<?php _e('Save all settings', 'adinj') ?>" />
	<h3><a name="random_home"></a><?php _e("Home page: Randomly Injected ad settings", 'adinj') ?> (<?php echo get_bloginfo('url'); ?>)</h3>
	<div class="inside" style="margin:10px">
	<p>These random ad injection settings are specific to your home page.</p>
	
	<?php _e("Maximum number of injected ads: ", 'adinj') ?>
	<select name='max_num_of_ads_home_page'>
	<?php
	for ($value=0; $value<=10; ++$value){
		echo "<option value=\"$value\" ";
		if($ops['max_num_of_ads_home_page'] == $value) echo 'selected="selected"';
		echo ">$value</option>";
	}
	?>
	</select> <?php echo adinj_getdefault('max_num_of_ads_home_page'); ?><br />
	
	<p><span style="font-size:10px;"><b>Docs:</b> On a multi-post home page, one randomly positioned advert will be inserted into each post, up to the maximum number specified here.</span></p>
	
	<?php adinj_postbox_end(); ?>
	
	
	
	<?php adinj_postbox_start(__("Optional top advert (single posts and pages only)", 'adinj'), 'topad'); ?>
	
	<?php
		_e("Only show top ad on pages longer than: ", 'adinj');
		adinj_selection_box("top_ad_if_longer_than",
			array(ADINJ_RULE_DISABLED, 100, 200, 300, 500, 1000, 1500, 2000, 2500, 3000, 5000, 10000, 20000, ADINJ_ALWAYS_SHOW));
			
	?>

	<br clear="all" />
	
	<table border="0">
	<tr><td>
	<textarea name="ad_code_top_1" rows="10" cols="60"><?php echo $ops['ad_code_top_1']; ?></textarea>
	</td><td style="vertical-align: top">
	<?php adinj_add_alignment_options('top_'); ?>
	</td></tr>
	</table>
	<span style="font-size:10px;">The top ad is in addition to the quantity of other ads selected.</span>
	
	<p><span style="font-size:10px;"><b>Docs:</b> The top ad will only appear on single posts and pages. It will not appear on multi-post pages. Try a <a href="#468x15">468x15</a> or <a href="#336x280">336x280</a> advert.</span></p>
	
	<?php adinj_postbox_end(); ?>
	
	
	<?php adinj_postbox_start(__("Optional bottom advert (single posts and pages only)", 'adinj'), 'bottomad'); ?>
	
	<?php
		_e("Only show bottom ad on pages longer than: ", 'adinj');
		adinj_selection_box("bottom_ad_if_longer_than",
			array(ADINJ_RULE_DISABLED, 100, 200, 300, 500, 1000, 1500, 2000, 2500, 3000, 5000, 10000, 20000, ADINJ_ALWAYS_SHOW));
	?>
	
	<br clear="all"/>
	
	<table border="0">
	<tr><td>
	<textarea name="ad_code_bottom_1" rows="10" cols="60"><?php echo $ops['ad_code_bottom_1']; ?></textarea>
	</td><td style="vertical-align: top">
	<?php adinj_add_alignment_options('bottom_'); ?>
	</td></tr>
	</table>
	<span style="font-size:10px;">The top ad is in addition to the quantity of other ads selected.</span>
	
	<p><span style="font-size:10px;"><b>Docs:</b> The bottom ad will only appear on single posts and pages. It will not appear on multi-post pages. Try a <a href="#336x280">336x280</a> advert.</span></p>
	
	
	<?php adinj_postbox_end(); ?>
	
	
	<?php adinj_postbox_start(__("Widget settings (sidebar ads)", 'adinj'), 'widgets'); ?>
	
	<p>You must configure your individual widgets from the <a href="widgets.php">widgets control panel</a>. However these settings are global to all widgets. Also note that the main set of <a href="#global">global settings</a> will override these ones.</p>

	<table border="0">
	
	<tr><td>
	<p>Don't show widget ads on these page types:</p>
	</td><td>
	<input type="checkbox" name="widget_exclude_home" <?php echo adinj_ticked('widget_exclude_home'); ?> />home - <?php echo get_bloginfo('url'); ?><br />
	<input type="checkbox" name="widget_exclude_page" <?php echo adinj_ticked('widget_exclude_page'); ?> />page - <?php echo $count_pages->publish; ?> page(s)<br />
	<input type="checkbox" name="widget_exclude_single" <?php echo adinj_ticked('widget_exclude_single'); ?> />single - <?php echo $count_posts->publish; ?> individual blog post(s)<br />
	<input type="checkbox" name="widget_exclude_archive" <?php echo adinj_ticked('widget_exclude_archive'); ?> />archive - includes category, tag, author, and date pages types<br />
	</td></tr>
	
	</table>
	
	
	<?php adinj_postbox_end(); ?>
	
	
	<?php adinj_postbox_start(__("Ad insertion mode and dynamic ad display restrictions", 'adinj'), 'restrictions'); ?>
	
	<h4>Ad insertion mode</h4>
	
	<blockquote>
	<p><input type="radio" name="ad_insertion_mode" value="mfunc" <?php if ($ops['ad_insertion_mode']=='mfunc') echo 'checked="checked"'; ?> /> <b>Use mfunc tags for dynamic features</b> - Dynamic features will work with WP Super Cache in legacy mode (or with a caching program that is compatible with WP Super Cache's mfunc tags). Dynamic features will also work if you don't use a caching program, although if you don't use a caching program 'direct' insertion will be more efficient.</p>
	<p><input type="radio" name="ad_insertion_mode" value="direct_dynamic" <?php if ($ops['ad_insertion_mode']=='direct_dynamic') echo 'checked="checked"'; ?> /> <b>Direct ad insertion with dynamic features</b> - Dynamic features will work if no caching is used. Only select this if you are not using any caching plugin.</p>
	<p><input type="radio" name="ad_insertion_mode" value="direct_static" <?php if ($ops['ad_insertion_mode']=='direct_static') echo 'checked="checked"'; ?> /> <b>Direct static ad insertion</b> - No dynamic feature support. Select this if you are using a caching plugin which is not compatible with WP Super Cache's mfunc tags.</p>
	</blockquote>
	</div>
	<p></p>
	
	<script type="text/javascript">
	jQuery(document).ready(function(){
	jQuery('input[name=ad_insertion_mode]:radio').change(function() {
		if (jQuery('input[name=ad_insertion_mode]:checked').val() == "direct_static"){
			jQuery('.dynamic_features').slideUp(1000);
			jQuery('.dynamic_features_msg').slideDown(1000);
		} else {
			jQuery('.dynamic_features_msg').slideUp(1000);
			jQuery('.dynamic_features').slideDown(1000);
		}
		return true;
		});
	});
	</script>
	
	<?php if ($ops['ad_insertion_mode'] == 'direct_static') { ?>
	<div class="dynamic_features_msg">
	<?php } else { ?>
	<div class="dynamic_features_msg" style="display:none">
	<?php } ?>
	<div class="inside" style="margin:10px">
	<b><span style="font-size:10px;color:red;">Note: Dynamic features (restricting ad views by referrer and IP address) are only available in the mfunc, or direct dynamic modes.</span></b>
	</div>
	</div>
	
	<?php if ($ops['ad_insertion_mode'] == 'direct_static') { ?>
	<script type="text/javascript">
	document.write('<style type="text/css" media="screen">#dynamic_features { display: none; }</style>');
	</script>
	<?php } ?>
	<div id="dynamic_features" class="dynamic_features">
	
	<div class="inside" style="margin:10px">

	<h4><a name="dynamic"></a>Show ads only to search engine visitors (dynamic feature)</h4>
	
	<blockquote>
	<input type="checkbox" name="sevisitors_only" <?php echo adinj_ticked('sevisitors_only'); ?> /><?php _e("Only show ads to search engine visitors (customise search engine referrers below if necessary).", 'adinj') ?><br />
	<textarea name="ad_referrers" rows="2" cols="70"><?php echo $ops['ad_referrers']; ?></textarea>
	<p>Comma separated list e.g.: <br /><code>.google., .bing., .yahoo., .ask., search?, search., /search/</code></p>
	</blockquote>
	
	<h4>Blocked IP addresses (dynamic feature)</h4>
	
	<blockquote>
	<textarea name="blocked_ips" rows="4" cols="70"><?php echo $ops['blocked_ips']; ?></textarea>
	<p>Comma separated list e.g.: <br /><code>0.0.0.1, 0.0.0.2</code></p>
	<p>Or you can list one IP per line with optional comments e.g.</p>
	<code style="padding:0px 0px">192.168.0.1<br />0.0.0.2<br /><?php echo $_SERVER['REMOTE_ADDR'] ?> //my ip<br />0.0.0.3</code>
	
	<p>For reference your current IP address is <code><?php echo $_SERVER['REMOTE_ADDR'] ?></code></p>
	</blockquote>
	</div>
	
	
	<h3>Recommended WP Super Cache settings:</h3>
	<div class="inside" style="margin:10px">

	<blockquote>
		<ul>
		<li>Cache hits to this website for quick access.</li>
		<li>Legacy page caching.</li>
		<li>Compress pages so they&#x2019;re served more quickly to visitors.</li>
		<li>Expire time: 36000 (10 hours). Or 3600 (1 hour) for very busy site.</li>
		</ul>
	</blockquote>
	
	<p>
	<?php if (is_plugin_active('wp-super-cache/wp-cache.php')) {
		echo "Go to the WP Super Cache <a href='options-general.php?page=wpsupercache&amp;tab=settings'>advanced settings page</a> (where you can set the caching mode to Legacy).";
	} else {
		echo "Note: WP Super Cache does not appear to be active.";
	} ?>
	</p>
	</div>
	
	</div>
	
	<?php adinj_postbox_end(); ?>
	
	
	<?php adinj_postbox_start(__("Debugging", 'adinj'), 'debugging'); ?>
	
	<input type="checkbox" name="debug_mode" <?php echo adinj_ticked('debug_mode'); ?> />Enable debug mode
	
	<p>If you are not sure why ads aren't appearing, or why they are appearing, enable debug mode and look at the debug information (search for 'ADINJ DEBUG') in the HTML of your content pages.</p>
	
	<?php
	
	if (adinj_problem_with_wpminify_check()){
		echo adinj_get_problem_with_wpminify_message();
	}
	
	adinj_debug_information();
	?>
	
	<p></p>
	
	<p>If you want to restore all settings (excluding the ad contents) to their default values use this button.</p>
	
	<input type="submit" name="adinj_action" value="<?php _e('Reset to Default', 'adinj') ?>" />
	
	<p>You can delete the database settings if you are going to uninstall Ad Injection.</p>
	
	<input type="submit" name="adinj_action" value="<?php _e('Delete settings from DB', 'adinj') ?>" />
	
	<?php adinj_postbox_end(); ?>


	<br clear="all" />
	
	<?php
	
	adinj_docs();
	
	echo '</form>';
	echo '</div> <!--wrap-->';
}

function adinj_postbox_start($title, $anchor, $width='650px'){
	$ops = adinj_options();
	?>
	<div class='postbox-container' style='width:<?php echo $width; ?>;float:left; clear:left;'>
	<div class="metabox-holder">
	<div class="postbox">
	<input type="submit" style="float:right" class="button-primary" name="adinj_action" value="<?php _e('Save all settings', 'adinj') ?>" />
	<div class="<?php echo $anchor; ?>-button"></div>
	<script type="text/javascript">
	jQuery(document).ready(function(){
	jQuery('.<?php echo $anchor; ?>-button').show().before('<a href="#" style="float:right" id="toggle-<?php echo $anchor; ?>" class="button">Show/Hide</a>');
	jQuery('a#toggle-<?php echo $anchor; ?>').click(function() {
		jQuery('#ui_<?php echo $anchor; ?>_hide').val(!jQuery('.<?php echo $anchor; ?>-box').is(":hidden"));
		jQuery('.<?php echo $anchor; ?>-box').slideToggle(1000);
		return false;
		});
	});
	</script>
	<input type='hidden' id='ui_<?php echo $anchor; ?>_hide' name='ui_<?php echo $anchor; ?>_hide' value='<?php echo $ops['ui_'.$anchor.'_hide']; ?>' />
	<h3><?php $info = adinj_get_status($anchor); echo adinj_dot($info[0]); ?> <a name="<?php echo $anchor; ?>"></a><?php echo adinj_get_logo() . ' ' . $title; ?></h3>
	<?php if($ops['ui_'.$anchor.'_hide'] == 'true'){ ?>
	<script type="text/javascript">
        document.write('<style type="text/css" media="screen">#<?php echo $anchor; ?>-box { display: none; }</style>');
	</script>
	<div id="<?php echo $anchor; ?>-box" class="<?php echo $anchor; ?>-box">
	<?php } else { ?>
	<div class="<?php echo $anchor; ?>-box">
	<?php } ?>
	<div class="inside" style="margin:10px">

	<?php
}

function adinj_postbox_end(){
	echo '
	</div> <!--inside-->
	</div> <!--anchor-box-->
	</div> <!--postbox-->
	</div> <!--metabox-holder-->
	</div> <!--postbox-container-->';
}

function adinj_get_status($name){
	$ops = adinj_options();
	$status[] = 'black';
	$status[] = 'Error...';
	if ($name == 'global'){
		if ($ops['exclude_home'] == 'on' &&
			$ops['exclude_page'] == 'on' &&
			$ops['exclude_single'] == 'on' &&
			$ops['exclude_archive'] == 'on'){
			$status[0] = 'red';
			$status[1] = 'excluded from all';
			return $status;
		}
		$val = $ops['ads_enabled'];
		if ($val == 'on'){
			$status[0] = 'green';
			$status[1] = $val;
		} else if ($val == 'off' || $val == ''){
			$status[0] = 'red';
			$status[1] = $val;
		} else if ($val == 'test'){
			$status[0] = 'orange';
			$status[1] = 'test mode';
		}
	} else if ($name == 'random'){
		$ad = $ops['ad_code_random_1'];
		if (empty($ad)){
			$status[0] = 'red';
			$status[1] = 'no ad defined';
			return $status;
		}
		$val = $ops['max_num_of_ads'];
		if ($val == '0'){
			$status[0] = 'red';
			$status[1] = 'off';
		} else {
			$status[0] = 'green';
			$status[1] = 'max ads: ' . $val;
		}
	} else if ($name == 'random_home'){
		$val = $ops['max_num_of_ads_home_page'];
		$msg = '<a href="#';
		if ($val == 0){
			$status[0] = 'red';
			$msg .= 'random_home">0 on home';
		} else if ($ops['exclude_home'] == 'on'){
			$status[0] = 'red';
			$msg .= 'global">exclude from home';
		} else {
			$status[0] = 'green';
			$msg .= 'random_home">max ads: ' . $val .' (home)';
		}
		$status[1] = $msg.'</a>';
	} else if ($name == 'topad'){
		$ad = $ops['ad_code_top_1'];
		if (empty($ad)){
			$status[0] = 'red';
			$status[1] = 'no ad defined';
			return $status;
		}
		$val = $ops['top_ad_if_longer_than'];
		if ($val == ADINJ_RULE_DISABLED){
			$status[0] = 'red';
			$status[1] = 'off';
		} else {
			$status[0] = 'green';
			$status[1] = 'on';
		}
	} else if ($name == 'bottomad'){
		$ad = $ops['ad_code_bottom_1'];
		if (empty($ad)){
			$status[0] = 'red';
			$status[1] = 'no ad defined';
			return $status;
		}
		$val = $ops['bottom_ad_if_longer_than'];
		if ($val == ADINJ_RULE_DISABLED){
			$status[0] = 'red';
			$status[1] = 'off';
		} else {
			$status[0] = 'green';
			$status[1] = 'on';
		}
	} else if ($name == 'widgets'){
		if ($ops['widget_exclude_home'] == 'on' &&
			$ops['widget_exclude_page'] == 'on' &&
			$ops['widget_exclude_single'] == 'on' &&
			$ops['widget_exclude_archive'] == 'on'){
			$status[0] = 'red';
			$status[1] = 'exclude from all';
		} else {
			$status[1] = 'see <a href="widgets.php">widgets</a> screen';
		}
	} else if ($name == 'mode'){
		$status[1] = $ops['ad_insertion_mode'];
	} else if ($name == 'restrictions'){
		if ($ops['ad_insertion_mode'] == 'direct_static'){
			$status[1] = 'n/a for direct static';
			return $status;
		}
		$status[1] = "";
		if ($ops['sevisitors_only'] == 'on'){
			$status[1] .= 'referrer';
		}
		if (!empty($ops['blocked_ips'])){
			$status[1] .= ' ip';
		}
	} else if ($name == 'debugging'){
		$val = $ops['debug_mode'];
		if ($val == 'on'){
			$status[0] = 'green';
			$status[1] = 'on';
		} else {
			$status[0] = 'red';
			$status[1] = 'off';
		}
	}
	return $status;
}

// This is for 'exclude' options so 'on' is red.
function adinj_green_or_red_dot($option){
	$ops = adinj_options();
	if ($ops[$option] == 'on'){
		return adinj_dot('red');
	} else {
		return adinj_dot('green');
	}
}

function adinj_dot($colour){
	return '<span style="color:'.$colour.'">&#x25cf;</span>';
}

function adinj_selection_box($name, $values, $type=NULL){
	echo "<select name='$name'>";
	$ops = adinj_options();
	$selected_value = $ops[$name];
	foreach ($values as $value){
		echo "<option value=\"$value\" ";
		if($selected_value == "$value") echo 'selected="selected"';
		if (empty($type) && is_numeric($value)){
			$typetxt = "(chars)";
		} else {
			$typetxt = $type;
		}
		if ($value === ADINJ_RULE_DISABLED || $value === '') $typetxt = "";
		echo ">$value $typetxt</option>";
	}
	echo "</select>";
}

function adinj_condition_table($name, $description, $type){
	$options = adinj_options();
	?>
	<table border="0">
	<tr><td>
	
	<textarea name="<?php echo $name; ?>_condition_entries" rows="2" cols="40"><?php echo $options[$name.'_condition_entries']; ?></textarea>
	
	
	</td><td style="vertical-align:top">
	
	<?php
		adinj_selection_box($name."_condition_mode",
			array('Only show in', 'Never show in'));
	?>
	
	<br />
	
		<?php if ($type == 'category') { ?>
	<select name="<?php echo $name; ?>_dropdown" onchange='adinj_addtext(<?php echo $name; ?>_condition_entries, this.options[this.selectedIndex].value);'>
		<option value=""><?php echo 'Add ' . $type; ?></option> 
		<?php 
		$categories = get_categories(); 
		foreach ($categories as $category) {
			$option = '<option value="'.$category->category_nicename.'">';
			$option .= $category->category_nicename;
			$option .= ' ('.$category->category_count.')';
			$option .= '</option>';
			echo $option;
		}
		?>
	</select>
	<NOSCRIPT><br /><span style="font-size:10px">As JavaScript is disabled you will have to manually type in the values.</span></NOSCRIPT>

	<?php } else if ($type == 'tag') { ?>
	
	<select name="<?php echo $name; ?>_dropdown" onchange='adinj_addtext(document.adinjform.<?php echo $name; ?>_condition_entries, this.options[this.selectedIndex].value);'">
	
		<option value=""><?php echo 'Add ' . $type; ?></option> 
		<?php 
		$tags = get_tags(); 
		foreach ($tags as $tag) {
			$option = '<option value="'.$tag->slug.'">';
			$option .= $tag->slug;
			$option .= ' ('.$tag->count.')';
			$option .= '</option>';
			echo $option;
		}
		?>
	</select>
	<NOSCRIPT><br /><span style="font-size:10px">As JavaScript is disabled you will have to manually type in the values.</span></NOSCRIPT>
	
	<?php } else {
		echo 'Type not defined: ' . $type;
	}?>
	
	</td></tr>
	<tr><td colspan="2">
	<span style="font-size:10px;">Comma separated list of <?php echo $description; ?></span>
	</td></tr>
	</table>
	<?php
}

function adinj_add_alignment_options($prefix){
	_e("Alignment", 'adinj');
	echo "<br />";
	adinj_selection_box($prefix.'align',
		array(ADINJ_RULE_DISABLED, 'left', 'center', 'right', 'float left', 'float right'));

	echo "<br />";

	_e("Clear (CSS)", 'adinj');
	echo "<br />";
	adinj_selection_box($prefix.'clear',
		array(ADINJ_RULE_DISABLED, 'left', 'right', 'both'));

	echo "<br />";
	
	_e("Margin top", 'adinj');
	echo "<br />";
	adinj_selection_box($prefix.'margin_top',
		array(ADINJ_RULE_DISABLED, 0, 1, 2, 3, 4, 5, 7, 10, 15, 20, 30), "(px)");
	
	echo "<br />";
	
	_e("Margin bottom", 'adinj');
	echo "<br />";
	adinj_selection_box($prefix.'margin_bottom',
		array(ADINJ_RULE_DISABLED, 0, 1, 2, 3, 4, 5, 7, 10, 15, 20, 30), "(px)");
}

function adinj_debug_information(){
	$stored_options = adinj_options();
	$default_options = adinj_default_options();
	?>
	<h4>Settings dump from database (all in 'adinj_options' option)</h4>
	<table border="1" style="width:610px; table-layout:fixed; word-wrap:break-word;">
	<tr><td><b>Name</b></td><td><b>Stored</b></td><td><b>Default</b></td></tr>
	<?php
	if ($stored_options !== false){
		$count = 0;
		foreach ($stored_options as $key => $value){
			if ($count % 2 == 0){
				echo '<tr style="background-color:#cccccc"><td>';
			} else {
				echo '<tr><td>';
			}
			echo "$key";
			echo "</td><td>";
			$value = htmlentities($value);
			echo "$value";
			echo "</td><td>";
			echo $default_options[$key];
			echo "</td></tr>";
			$count++;
		}
	} else {
		echo "<br />No options in database!";
	}
	echo '</table>';
	
	echo '<h4>Other settings</h4><blockquote>';
	
	echo 'ADINJ_PATH='.ADINJ_PATH.'<br />';
	echo 'ADINJ_CONFIG_FILE='.ADINJ_CONFIG_FILE.'<br />';
	echo 'ADINJ_AD_PATH='.ADINJ_AD_PATH.'<br />';
	
	echo 'Plugin version='.adinj_get_version();
	echo '</blockquote>';
	
	global $adinj_warning_msg_filewrite;
	if (!empty($adinj_warning_msg_filewrite)){
		echo "<h4>Errors on 'Save all settings'</h4><blockquote>$adinj_warning_msg_filewrite</blockquote";
	}
	
	global $adinj_warning_msg_chmod;
	if (!empty($adinj_warning_msg_chmod)){
		echo "<h4>Warnings on 'Save all settings'</h4><blockquote>$adinj_warning_msg_chmod</blockquote";
	}
	
}

function adinj_get_version(){
	$plugin_data=get_plugin_data(ADINJ_PATH . '/ad-injection.php');
	return $plugin_data['Version'];
}

function adinj_problem_with_wpminify_check(){
	$wpm_options = get_option('wp_minify');
	if ($wpm_options['enable_html'] == true && is_plugin_active('wp-super-cache/wp-cache.php')){
		return true;
	}
	return false;
}

function adinj_get_problem_with_wpminify_message(){
	return '<font color="red">Problem: Ad Injection will not work if WP Minify is set to minify HTML whilst WP Super Cache is enabled.</font><br />
			Solution: Go to <a href="options-general.php?page=wp-minify">the WP Minify settings page</a> and untick "Enable HTML Minification".';
}

function adinj_init_warning() {
	if (stripos($_SERVER["PHP_SELF"], 'plugins.php') !== false){
		echo '<div id="ad-injection-warning" class="updated fade"><p><strong>
		Ad Injection needs configuring:
		Go to <a href="options-general.php?page=ad-injection.php">the settings page</a> to configure and enable your ads.
		</strong></p></div>
		';
	}
	// TODO add option to disable message without having to go to settings.
}

function adinj_compatibility_checks() {
	if (stripos($_SERVER["PHP_SELF"], 'ad-injection') !== false){
		$wpm_options = get_option('wp_minify');
		if ($wpm_options['enable_html'] == true){
			echo '<div id="ad-injection-error" class="error"><p><strong>';
			echo adinj_get_problem_with_wpminify_message();
			echo '</strong></p></div>';
		}
	}
}

function adinj_activate_hook() {
	$stored_options = adinj_options();
	$pending_options = adinj_default_options();
	if(empty($stored_options)){
		// Save defaults to DB below.
		if (!is_plugin_active('wp-super-cache/wp-cache.php')){
			$pending_options['ad_insertion_mode'] = 'direct_dynamic';
		}
	} else {
		// Upgrade options if necessary. Use default as a baseline,
		// and then overwrite default with the saved ones.
		foreach ($pending_options as $key => $value){
			if (array_key_exists($key, $stored_options)){
				$pending_options[$key] = $stored_options[$key];
			}
		}
	}
	
	$random_file2 = ADINJ_AD_PATH.'/'.ADINJ_AD_RANDOM_FILE;
	$top_file2 = ADINJ_AD_PATH.'/'.ADINJ_AD_TOP_FILE;
	$bottom_file2 = ADINJ_AD_PATH.'/'.ADINJ_AD_BOTTOM_FILE;
	if ($pending_options['ad_insertion_mode'] == 'mfunc'){
		// Restore data after automatic upgrade
		// TODO could remove this code further down the line when everyone
		// has moved to the new ad store location
		if (!@file_exists($random_file2) && !empty($pending_options['ad_code_random_1'])){
			write_ad_to_file($pending_options['ad_code_random_1'], $random_file2);
		}
		if (!@file_exists($top_file2) && !empty($pending_options['ad_code_top_1'])){
			write_ad_to_file($pending_options['ad_code_top_1'], $top_file2);
		}
		if (!@file_exists($bottom_file2) && !empty($pending_options['ad_code_bottom_1'])){
			write_ad_to_file($pending_options['ad_code_bottom_1'], $bottom_file2);
		}
		if (!@file_exists(ADINJ_CONFIG_FILE)){
			adinj_write_config_file();
		}
	}

	adinj_update_options($pending_options);
}

// If the options in the database are out of sync with our default options
// then the database options will need upgrading
function adinj_options_need_upgrading($stored_options){
	$default_options = adinj_default_options();
	foreach ($default_options as $key => $value){
		if (!array_key_exists($key, $stored_options)){
			return true;
		}
	}
	foreach ($stored_options as $key => $value){
		if (!array_key_exists($key, $default_options)){
			return true;
		}
	}
	return false;
}

function adinj_default_options(){
	return array(
		// Global settings
		'ads_enabled' => 'off',
		'ads_on_page_older_than' => '10',
		'exclude_home' => '',
		'exclude_page' => '',
		'exclude_single' => '',
		'exclude_archive' => '',
		'global_category_condition_mode' => ADINJ_ONLY_SHOW_IN,
		'global_category_condition_entries' => '',
		'global_tag_condition_mode' => ADINJ_ONLY_SHOW_IN,
		'global_tag_condition_entries' => '',
		// Random ad
		'ad_code_random_1' => '',
		'max_num_of_ads' => '2', // single posts and pages
		'no_random_ads_if_shorter_than' => '100',
		'one_ad_if_shorter_than' => '500',
		'two_ads_if_shorter_than' => '1000',
		'three_ads_if_shorter_than' => ADINJ_RULE_DISABLED,
		'top_ad_if_longer_than' => ADINJ_RULE_DISABLED,
		'bottom_ad_if_longer_than' => ADINJ_RULE_DISABLED,
		'rnd_align' => ADINJ_RULE_DISABLED,
		'rnd_clear' => ADINJ_RULE_DISABLED,
		'rnd_margin_top' => '3',
		'rnd_margin_bottom' => '3',
		'first_paragraph_ad' => '',
		'multiple_ads_at_same_position' => '',
		// Home page specific random ads
		'max_num_of_ads_home_page' => '3',
		// top
		'ad_code_top_1' => '',
		'top_align' => ADINJ_RULE_DISABLED,
		'top_clear' => ADINJ_RULE_DISABLED,
		'top_margin_top' => '3',
		'top_margin_bottom' => '3',
		// bottom
		'ad_code_bottom_1' => '',
		'bottom_align' => ADINJ_RULE_DISABLED,
		'bottom_clear' => ADINJ_RULE_DISABLED,
		'bottom_margin_top' => '3',
		'bottom_margin_bottom' => '3',
		// widgets
		'widget_exclude_home' => '',
		'widget_exclude_page' => '',
		'widget_exclude_single' => '',
		'widget_exclude_archive' => '',
		// dynamic features
		'sevisitors_only' => '',
		'ad_referrers' => '.google., .bing., .yahoo., .ask., search?, search., /search/',
		'blocked_ips' => '',
		'ad_insertion_mode' => 'mfunc',
		// ui
		'ui_global_hide' => 'false',
		'ui_random_hide' => 'false',
		'ui_topad_hide' => 'false',
		'ui_bottomad_hide' => 'false',
		'ui_widgets_hide' => 'false',
		'ui_restrictions_hide' => 'false',
		'ui_debugging_hide' => 'true',
		'ui_docs_hide' => 'false',
		'ui_testads_hide' => 'false',
		// debug
		'debug_mode' => ''
	);
}

function adinj_getdefault($option){
	$default_options = adinj_default_options();
	return "(default: " . $default_options[$option] . ")";
}

function write_ad_to_file($ad, $ad_path){
		adinj_write_file($ad_path, $ad, 0640);
}

function adinj_docs(){
?>
<hr />

<?php adinj_postbox_start(__("Quick Start", 'adinj'), "docs", '95%'); ?>

<p>1. Copy and paste your ad code into the ad code boxes.</p>

<p>2. Choose how many ads of each type you want displayed.</p>

<p>3. Configure any ad positioning (optional).</p>

<p>4. Check the ad insertion mode (in the Insertion mode and ad display restriction section).</p>

<p>5. If you are using a compatible ad insertion mode you may configure dynamic ad display restrictions. i.e. showing ads only to certain people (e.g. search engine visitors), or blocking ads from specific IPs.</p>

<p>6. Enable your ads (tick box at the very top).</p>
</div>

<h3><?php echo adinj_get_logo(); ?> Supported in-page tags</h3>
<div class="inside" style="margin:10px">

<p>These tags can be inserted into the page source to override the configured behaviour on individual pages. Because sometimes specific pages need to be treated differently.</p>

<ul>
<li><code>&lt;!--noadsense--&gt;</code> OR <code>&lt;!-no-adsense--&gt;</code> OR <code>&lt;!--NoAds--&gt;</code> OR <code>&lt;!--OffAds--&gt;</code> - disables all ads on this page. These tags are here to make this plugin compatible with the tags from Adsense Injection, Whydowork Adsense and Quick Adsense.</li>
</ul>

<p></p>

<ul>
<li><code>&lt;!--adsandwich--&gt;</code> - Inserts the top and bottom ad but no random ads. Disables all other ads.</li>
<li><code>&lt;!--adfooter--&gt;</code> - Insert a single ad at the very bottom. Disables all other ads.</li>
</ul>

<p></p>

<ol>
<li><code>&lt;!--adsensestart--&gt;</code> - Random ads will start from this point*. For compatibility with Adsense Injection.</li>
<li><code>&lt;!--adsenseend--&gt;</code> - Random ads will not be inserted after this point*. New tag but I've kept the Adsense Injection naming convention to make it fit with the above tag.</li>
<li><code>&lt;!--adstart--&gt;</code> - Random ads will start from this point*.</li>
<li><code>&lt;!--adend--&gt;</code> - Random ads will not be inserted after this point*.</li>
</ol>

<p>These four tags will not affect the top and bottom ad.</p>

<h4>Custom field for disabling adverts</h4>

<p>To disable all adverts on the page you can also set the custom <code>disable_adverts</code> field to '1' from the WordPress post editor.</p>


<?php adinj_postbox_end(); ?>


<?php adinj_postbox_start(__("Test Adverts", 'adinj'), "testads", '95%'); ?>

<p>You can copy and paste these adverts into the boxes above to test your ad setup before switching to your real ads.</p>

<h4><a name="468x60"></a>468x60 banner</h4>

<p><textarea onclick="javascript:this.focus();this.select();" style="min-height:50px;" cols="80" rows="4">&lt;div style=&quot;background-color:#ff9999; width:468px; height:60px;&quot;&gt;
&lt;h5&gt;TEST ADVERT 468x60 - &lt;a href=&quot;http://www.reviewmylife.co.uk/&quot;&gt;www.reviewmylife.co.uk&lt;/a&gt;&lt;/h5&gt;
&lt;/div&gt;</textarea></p>

<div style="background-color:#99ffff; width:468px; height:60px;">
<h5>TEST ADVERT 468x60 - <a href="http://www.reviewmylife.co.uk/">www.reviewmylife.co.uk</a></h5>
</div><p></p>

<h4><a name="728x90"></a>728x90 banner</h4>

<p><textarea onclick="javascript:this.focus();this.select();" style="min-height:50px;" cols="80" rows="4">&lt;div style=&quot;background-color:#ff9999; width:728px; height:90px;&quot;&gt;
&lt;h5&gt;TEST ADVERT 728x90&lt;/h5&gt;
&lt;a href=&quot;http://www.reviewmylife.co.uk/&quot;&gt;www.reviewmylife.co.uk&lt;/a&gt;&lt;br /&gt;
&lt;a href=&quot;http://www.advancedhtml.co.uk/&quot;&gt;www.advancedhtml.co.uk&lt;/a&gt;
&lt;/div&gt;</textarea></p>

<div style="background-color:#ff9999; width:728px; height:90px;">
<h5>TEST ADVERT 728x90</h5>
<a href="http://www.reviewmylife.co.uk/">www.reviewmylife.co.uk</a><br />
<a href="http://www.advancedhtml.co.uk/">www.advancedhtml.co.uk</a>
</div><p></p>

<h4>160x90 link unit</h4>

<p><textarea onclick="javascript:this.focus();this.select();" style="min-height:50px;" cols="80" rows="4">&lt;div style=&quot;background-color:#ccff99; width:160px; height:90px;&quot;&gt;
&lt;h5&gt;TEST ADVERT 160x90&lt;/h5&gt;
&lt;a href=&quot;http://www.reviewmylife.co.uk/&quot;&gt;reviewmylife.co.uk&lt;/a&gt;&lt;br /&gt;
&lt;a href=&quot;http://www.advancedhtml.co.uk/&quot;&gt;advancedhtml.co.uk&lt;/a&gt;
&lt;/div&gt;</textarea></p>

<div style="background-color:#ccff99; width:160px; height:90px;">
<h5>TEST ADVERT 160x90</h5>
<a href="http://www.reviewmylife.co.uk/">reviewmylife.co.uk</a>
<a href="http://www.advancedhtml.co.uk/">advancedhtml.co.uk</a><br />
</div><p></p>

<h4><a name="468x15"></a>468x15 link unit</h4>

<p><textarea onclick="javascript:this.focus();this.select();" style="min-height:50px;" cols="80" rows="4">&lt;div style=&quot;background-color:#cccc99; width:468px; height:15px;&quot;&gt;
&lt;font size=&quot;-2&quot;&gt;&lt;b&gt;TEST ADVERT 160x90&lt;/b&gt; &lt;a href=&quot;http://www.reviewmylife.co.uk/&quot;&gt;reviewmylife.co.uk&lt;/a&gt;&lt;/font&gt;
&lt;/div&gt;</textarea></p>

<div style="background-color:#cccc99; width:468px; height:15px;">
<font size="-2"><b>TEST ADVERT 160x90</b> <a href="http://www.reviewmylife.co.uk/">reviewmylife.co.uk</a></font>
</div><p></p>

<h4><a name="336x280"></a>336x280 large rectangle</h4>

<p><textarea onclick="javascript:this.focus();this.select();" style="min-height:50px;" cols="80" rows="4">&lt;div style=&quot;background-color:#ccccff; width:336px; height:280px;&quot;&gt;
&lt;h5&gt;TEST ADVERT 336x280 - &lt;a href=&quot;http://www.reviewmylife.co.uk/&quot;&gt;www.reviewmylife.co.uk&lt;/a&gt;&lt;/h5&gt;
&lt;/div&gt;</textarea></p>

<div style="background-color:#ccccff; width:336px; height:280px;">
<h5>TEST ADVERT 336x280 - <a href="http://www.reviewmylife.co.uk/">www.reviewmylife.co.uk</a></h5>
</div><p></p>

<h4>468x60 banner with dynamic PHP</h4>

<p>The PHP will execute if 1) WP Super Cache is turned on in legacy mode, and 2) if WP Super Cache is not installed/disabled.</p>

<p><textarea onclick="javascript:this.focus();this.select();" style="min-height:50px;" cols="80" rows="5">&lt;div style=&quot;background-color:#ffff99; width:468px; height:60px;&quot;&gt;
&lt;b&gt;TEST ADVERT 468x60 with date() and rand()&lt;/b&gt;&lt;br /&gt;
&lt;?php echo &quot;date=&quot;.date(&quot;Y-m-d H:i:s&quot;) .&quot; rand=&quot;.rand(); ?&gt;&lt;br /&gt;
&lt;a href=&quot;http://www.advancedhtml.co.uk/&quot;&gt;www.advancedhtml.co.uk&lt;/a&gt;
&lt;/div&gt;</textarea></p>

<div style="background-color:#ffff99; width:468px; height:60px;">
<b>TEST ADVERT 468x60 with date() and rand()</b><br />
<?php echo "date=".date("Y-m-d H:i:s") ." rand=".rand(); ?><br />
<a href="http://www.advancedhtml.co.uk/">www.advancedhtml.co.uk</a>
</div><p></p>

<?php adinj_postbox_end();

}

function adinj_init_hook() {
	$ops = adinj_options();
	if ($ops['ads_enabled'] != 'on') {
		add_action('admin_notices', 'adinj_init_warning');
	}
}

// init
add_action('init', 'adinj_init_hook');
// Config links
add_action('admin_menu', 'adinj_admin_menu_hook');
add_filter('plugin_action_links', 'adinj_options_link_hook', 10, 2); // digits = priority, num args

?>